@@ -3,23 +3,27 @@
 from __future__ import annotations
 
 import sys
-from sysconfig import get_config_vars, get_python_version
+from sysconfig import get_config_vars
 from typing import TYPE_CHECKING, Any, NoReturn
 
 import pytest
 from generate_samples import create_package, run_command
 
 from cx_Freeze import Executable, Freezer
-from cx_Freeze._compat import IS_MACOS, IS_MINGW, IS_WINDOWS, PLATFORM
+from cx_Freeze._compat import (
+    BUILD_EXE_DIR,
+    EXE_SUFFIX,
+    IS_CONDA,
+    IS_MACOS,
+    IS_MINGW,
+    IS_WINDOWS,
+    PYTHON_VERSION,
+)
 from cx_Freeze.exception import OptionError
 
 if TYPE_CHECKING:
     from pathlib import Path
 
-PYTHON_VERSION = get_python_version()
-BUILD_EXE_DIR = f"build/exe.{PLATFORM}-{PYTHON_VERSION}"
-SUFFIX = ".exe" if (IS_MINGW or IS_WINDOWS) else ""
-
 SOURCE = """
 hello.py
     print("Hello from cx_Freeze")
@@ -100,7 +104,7 @@ def test_freezer_default_bin_includes(tmp_path: Path, monkeypatch) -> None:
 
     freezer = Freezer(executables=[Executable("hello.py")])
     if IS_MACOS:
-        if sys.version_info[:2] <= (3, 10):
+        if sys.version_info[:2] <= (3, 10) or IS_CONDA:
             expected = f"libpython{PYTHON_VERSION}.dylib"
         else:
             expected = f"Python.framework/Versions/{PYTHON_VERSION}/Python"
@@ -363,7 +367,7 @@ def test_freezer_zip_filename(
         else:
             assert getattr(freezer, option) == value
 
-    executable = target_dir / f"hello{SUFFIX}"
+    executable = target_dir / f"hello{EXE_SUFFIX}"
     assert executable.is_file()
 
     output = run_command(tmp_path, executable, timeout=10)
